@@ -16,8 +16,6 @@
     *************************************************************************
 */
 
-#include <config-kopete.h>
-
 #include "kopetecontact.h"
 #include "kopetelistviewitem.h"
 #include "kopeteemoticons.h"
@@ -719,7 +717,6 @@ void DisplayNameComponent::redraw()
 
 	tokens = Kopete::Emoticons::tokenize( d->text );
 	ImageComponent *ic;
-	TextComponent *t;
 
 	QFontMetrics fontMetrics( d->font );
 	int fontHeight = fontMetrics.height();
@@ -728,7 +725,7 @@ void DisplayNameComponent::redraw()
 		switch ( (*token).type )
 		{
 		case KEmoticonsTheme::Text:
-			t = new TextComponent( this,  d->font, (*token).text );
+			new TextComponent( this,  d->font, (*token).text );
 		break;
 		case KEmoticonsTheme::Image:
 			ic = new ImageComponent( this );
@@ -826,7 +823,7 @@ ContactComponent::~ContactComponent()
 
 void ContactComponent::updatePixmap()
 {
-	setPixmap( contact()->onlineStatus().iconFor( contact(), d->iconSize ) );
+	setPixmap( contact()->onlineStatus().iconFor( contact() ).pixmap( d->iconSize ) );
 }
 Kopete::Contact *ContactComponent::contact()
 {
